@@ -6,12 +6,21 @@
 pfilter.internal <- function (object, params, Np,
                               tol, max.fail,
                               pred.mean, pred.var, filter.mean,
-                              .rw.sd, verbose,
+                              .rw.sd, seed, verbose,
                               save.states) {
+  if (missing(seed)) seed <- NULL
+  if (!is.null(seed)) {
+    if (!exists(".Random.seed",where=.GlobalEnv)) { # need to initialize the RNG
+      runif(1)
+    }
+    save.seed <- get(".Random.seed",pos=.GlobalEnv)
+    set.seed(seed)
+  }
+
   if (missing(params)) {
     params <- coef(object)
     if (length(params)==0) {
-      stop("pfilter error: ",sQuote("params")," must be supplied",call.=FALSE)
+      stop(sQuote("pfilter")," error: ",sQuote("params")," must be supplied",call.=FALSE)
     }
   }
   if (missing(Np))
@@ -31,7 +40,7 @@ pfilter.internal <- function (object, params, Np,
   }
   paramnames <- rownames(params)
   if (is.null(paramnames))
-    stop("pfilter error: ",sQuote("params")," must have rownames",call.=FALSE)
+    stop(sQuote("pfilter")," error: ",sQuote("params")," must have rownames",call.=FALSE)
 
   x <- init.state(object,params=params)
   statenames <- rownames(x)
@@ -50,9 +59,13 @@ pfilter.internal <- function (object, params, Np,
   if (random.walk) {
     rw.names <- names(.rw.sd)
     if (is.null(rw.names)||!is.numeric(.rw.sd))
-      stop("pfilter error: ",sQuote(".rw.sd")," must be a named vector",call.=FALSE)
+      stop(sQuote("pfilter")," error: ",sQuote(".rw.sd")," must be a named vector",call.=FALSE)
     if (any(!(rw.names%in%paramnames)))
-      stop("pfilter error: the rownames of ",sQuote("params")," must include all of the names of ",sQuote(".rw.sd"),"",call.=FALSE)
+      stop(
+           sQuote("pfilter")," error: the rownames of ",
+           sQuote("params")," must include all of the names of ",
+           sQuote(".rw.sd"),"",call.=FALSE
+           )
     sigma <- .rw.sd
   } else {
     rw.names <- character(0)
@@ -98,7 +111,7 @@ pfilter.internal <- function (object, params, Np,
              )
   else NULL
 
-  for (nt in seq(length=ntimes)) {
+  for (nt in seq_len(ntimes)) {
     
     ## advance the state variables according to the process model
     X <- try(
@@ -111,7 +124,7 @@ pfilter.internal <- function (object, params, Np,
              silent=FALSE
              )
     if (inherits(X,'try-error'))
-      stop("pfilter error: process simulation error",call.=FALSE)
+      stop(sQuote("pfilter")," error: process simulation error",call.=FALSE)
 
     x[,] <- X                 # ditch the third dimension
     
@@ -125,7 +138,7 @@ pfilter.internal <- function (object, params, Np,
                 silent=FALSE
                 )
       if (inherits(xx,'try-error')) {
-        stop("pfilter error: error in prediction mean computation",call.=FALSE)
+        stop(sQuote("pfilter")," error: error in prediction mean computation",call.=FALSE)
       } else {
         pred.m[,nt] <- xx
       }
@@ -136,7 +149,7 @@ pfilter.internal <- function (object, params, Np,
       problem.indices <- unique(which(!is.finite(x),arr.ind=TRUE)[,1])
       if (length(problem.indices)>0) {
         stop(
-             "pfilter error: non-finite state variable(s): ",
+             sQuote("pfilter")," error: non-finite state variable(s): ",
              paste(rownames(x)[problem.indices],collapse=', '),
              call.=FALSE
              )
@@ -145,7 +158,7 @@ pfilter.internal <- function (object, params, Np,
         problem.indices <- unique(which(!is.finite(params[rw.names,,drop=FALSE]),arr.ind=TRUE)[,1])
         if (length(problem.indices)>0) {
           stop(
-               "pfilter error: non-finite parameter(s): ",
+               sQuote("pfilter")," error: non-finite parameter(s): ",
                paste(rw.names[problem.indices],collapse=', '),
                call.=FALSE
                )
@@ -159,7 +172,7 @@ pfilter.internal <- function (object, params, Np,
                 silent=FALSE
                 )
       if (inherits(xx,'try-error')) {
-        stop("pfilter error: error in prediction variance computation",call.=FALSE)
+        stop(sQuote("pfilter")," error: error in prediction variance computation",call.=FALSE)
       } else {
         pred.v[,nt] <- xx
       }
@@ -177,10 +190,10 @@ pfilter.internal <- function (object, params, Np,
                    silent=FALSE
                    )
     if (inherits(weights,'try-error'))
-      stop("pfilter error: error in calculation of weights",call.=FALSE)
+      stop(sQuote("pfilter")," error: error in calculation of weights",call.=FALSE)
     if (any(is.na(weights))) {
       ## problem.indices <- which(is.na(weights))
-      stop("pfilter error: dmeasure returns NA",call.=FALSE)
+      stop(sQuote("pfilter")," error: ",sQuote("dmeasure")," returns NA",call.=FALSE)
     }
 
     ## test for failure to filter
@@ -192,7 +205,7 @@ pfilter.internal <- function (object, params, Np,
         message("filtering failure at time t = ",times[nt+1])
       nfail <- nfail+1
       if (nfail > max.fail)
-        stop('pfilter error: too many filtering failures',call.=FALSE)
+        stop(sQuote("pfilter")," error: too many filtering failures",call.=FALSE)
       loglik[nt] <- log(tol)          # worst log-likelihood
       weights <- rep(1/Np,Np)
       eff.sample.size[nt] <- 0
@@ -234,6 +247,12 @@ pfilter.internal <- function (object, params, Np,
 
   }
 
+  if (!is.null(seed)) {
+    assign(".Random.seed",save.seed,pos=.GlobalEnv)
+    seed <- save.seed
+  }
+
+
   list(
        pred.mean=pred.m,
        pred.var=pred.v,
@@ -241,6 +260,9 @@ pfilter.internal <- function (object, params, Np,
        eff.sample.size=eff.sample.size,
        cond.loglik=loglik,
        states=xparticles,
+       seed=seed,
+       Np=Np,
+       tol=tol,
        nfail=nfail,
        loglik=sum(loglik)
        )
@@ -256,6 +278,7 @@ setMethod(
                     pred.var = FALSE,
                     filter.mean = FALSE,
                     save.states = FALSE,
+                    seed = NULL,
                     verbose = getOption("verbose"),
                     ...) {
             pfilter.internal(
@@ -268,6 +291,7 @@ setMethod(
                              pred.var=pred.var,
                              filter.mean=filter.mean,
                              save.states=save.states,
+                             seed=seed,
                              verbose=verbose
                              )
           }
